import { useEffect, useState } from 'react';
import { Button, Form, Modal } from 'react-bootstrap';
import { useDispatch, useSelector } from 'react-redux';
import { fetchCampaigns } from '../store/slices/campaignSlice';
import SpinningComponent from './SpinningComponent';
import { addCreatorsToCampaign } from '../store/slices/creatorsSlice';

export default function AddToCampaign({ show, onHide }) {
    const dispatch = useDispatch();
    const { campaigns, status } = useSelector((state) => state.campaign);
    const { selectedCreators } = useSelector((state) => state.creators);
    const [campaignId, setCampaignId] = useState(null);
    const [validated, setValidated] = useState(false);

    useEffect(() => {
        if (show) {
            dispatch(fetchCampaigns());
        }

        return () => {
            setCampaignId(null);
            setValidated(false);
        };
    }, [show, dispatch]);

    const handleSubmit = async (e) => {
        const form = document.getElementById('campaignForm');
        if (form.checkValidity() === false) {
            e.preventDefault();
            e.stopPropagation();
            setValidated(true);
            return;
        }

        await dispatch(addCreatorsToCampaign({ creatorIds: selectedCreators, campaignId })).unwrap();
        onHide();
    };

    if (status === 'loading') {
        return <SpinningComponent />;
    }

    return (
        <Modal show={show} onHide={onHide}>
            <Modal.Header>
                <Modal.Title>Add to Campaign</Modal.Title>
            </Modal.Header>
            <Modal.Body>
                <Form id='campaignForm' noValidate validated={validated}>
                    <Form.Group>
                        <Form.Label>Campaign Name</Form.Label>
                        <Form.Select
                            type='select'
                            defaultValue=''
                            value={campaignId}
                            required
                            onChange={(e) => {
                                setCampaignId(e.target.value);
                            }}
                        >
                            <option value='' disabled selected>
                                Select Campaign
                            </option>
                            {campaigns.map((campaign) => (
                                <option key={campaign.id} value={campaign.id}>
                                    {campaign.name}
                                </option>
                            ))}
                        </Form.Select>
                        <Form.Control.Feedback type="invalid">
                            Please select a campaign.
                        </Form.Control.Feedback>
                    </Form.Group>
                </Form>
            </Modal.Body>
            <Modal.Footer>
                <Button variant='outline-primary' className='border-0' onClick={onHide}>
                    Cancel
                </Button>
                <Button variant='primary' onClick={handleSubmit}>
                    Add
                </Button>
            </Modal.Footer>
        </Modal>
    );
}
