import React from 'react';
import { useEffect } from 'react';
import { useSelector } from 'react-redux';
import { Link, useParams } from 'react-router-dom';
import { ChartNoAxesColumnIncreasing, CircleDollarSign, Edit, Eye, Folders, Hash, Layers, Tag, TrendingUp, UserRoundCheck } from 'lucide-react';
import Spinning from './SpinningComponent';

export default function CampaignList() {
    const { selectedBrand ,status } = useSelector((state) => state.brands);
    useEffect(() => {
        console.log(selectedBrand);
    }, [selectedBrand]);

  

    if (status === 'loading') {
        return <Spinning />;
    }

    if (selectedBrand?.campaigns?.length === 0) {
        return <div>No campaigns found</div>;
    }

    return (
        <div className='campaigns-list'>
            {selectedBrand?.campaigns?.length > 0 &&
                selectedBrand.campaigns.map((campaign) => (
                    <div className='campaign-info' key={campaign.id}>
                        <Link to={`/brands/${selectedBrand.id}/campaigns/${campaign.id}`} className='campaign-title'>
                            {campaign.name}
                        </Link>
                        <div className='campaign-item'>
                            <div className='campaign-item-label'><Layers size={18} />Service</div>
                            <div className='campaign-item-value'>{campaign.service}</div>
                        </div>
                        <div className='campaign-item'>
                            <div className='campaign-item-label'>Creator Type</div>
                            <div className='campaign-item-value'>{campaign.creator_type}</div>
                        </div>
                        <div className='campaign-item'>
                            <div className='campaign-item-label'><Hash size={18} />Creators</div>
                            <div className='campaign-item-value'>{campaign.creators_count}</div>
                        </div>
                        <div className='campaign-item'>
                            <div className='campaign-item-label'><ChartNoAxesColumnIncreasing size={18} />Creator Level</div>
                            <div className='campaign-item-value'>
                                {campaign.creator_level}
                                {/* {campaign.creator_level &&
                                    campaign.creator_level.map((level) => (
                                        <span className='creator-level-tag'>{level}</span>
                                    ))} */}
                            </div>
                        </div>
                        <div className='campaign-item'>
                            <div className='campaign-item-label'><Folders size={18} />Category</div>
                            <div className='campaign-item-value'>
                                {campaign.creator_category}
                                {/* {campaign.category &&
                                    campaign.category.map((cat) => <span className='category-tag'>{cat}</span>)} */}
                            </div>
                        </div>
                        <div className='campaign-item'>
                            <div className='campaign-item-label'><TrendingUp size={18} />GMV</div>
                            <div className='campaign-item-value'>{campaign.gmv}</div>
                        </div>
                        <div className='campaign-item'>
                            <div className='campaign-item-label'><UserRoundCheck size={18} />Followers</div>
                            <div className='campaign-item-value'>{campaign.followers}</div>
                        </div>
                        <div className='campaign-item'>
                            <div className='campaign-item-label'><Eye size={18} />Views</div>
                            <div className='campaign-item-value'>{campaign.views}</div>
                        </div>
                        <div className='campaign-item'>
                            <div className='campaign-item-label'><CircleDollarSign size={18} />Budget</div>
                            <div className='campaign-item-value'>{campaign.budget}</div>
                        </div>
                    </div>
                ))}
        </div>
    );
}
