import { LoaderCircle, Send, X } from 'lucide-react';
import { useEffect, useState } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { fetchCreatorDetail } from '../store/slices/creatorsSlice';
import { Button, Form } from 'react-bootstrap';
import { fetchConversationSummary, getRecommendedReply } from '../store/slices/chatSlice';

export default function ChatDetails({ onCloseChatDetails }) {
    const [search, setSearch] = useState('');
    const { currentChat } = useSelector((state) => state.chat);
    const { selectedCreator } = useSelector((state) => state.creators);
    const dispatch = useDispatch();

    const handleSubmit = (e) => {
        e.preventDefault();
        console.log('Form submitted');
        const query = {
            conversation_id: currentChat?.conversation_id,
            conversation_summary: currentChat?.summary?.summary || '',
            last_message: currentChat?.last_message || '',
            goal_id: '',
        };
        dispatch(getRecommendedReply(query));
    };

    const handleSendEmail = () => {
        console.log('Send email');
        if (!currentChat?.recommended_reply?.reply) return;

        const query = {
            conversation_id: currentChat?.conversation_id,
            body: currentChat?.recommended_reply?.reply,
            from_email: '',
            subject: '',
        };
        dispatch(getRecommendedReply(query));
    };

    useEffect(() => {
        dispatch(fetchCreatorDetail({ creatorId: currentChat?.negotiation?.creator?.id }));
        dispatch(fetchConversationSummary(currentChat?.conversation_id));
    }, [dispatch, currentChat]);

    return (
        <div className='chat-details'>
            <div className='chat-details-header'>
                <div className='chat-header-title'>
                    Chat Details
                    <div className='chat-detail-close-btn' onClick={onCloseChatDetails}>
                        <X />
                    </div>
                </div>
                <div className='chat-detail-header-creator'>
                    <div className='chat-detail-header-creator-avatar'>
                        <img src={selectedCreator?.creator?.avatar} alt={selectedCreator?.creator?.name} />
                    </div>
                    <div className='chat-detail-header-creator-name'>{selectedCreator?.creator?.name}</div>
                </div>
            </div>
            <div className='chat-detail-header-infos'>
                <div className='chat-detail-header-info-item'>
                    <div className='chat-detail-header-info-item-label'>Category</div>
                    <div className='chat-detail-header-info-item-value'>{selectedCreator?.business?.category}</div>
                </div>
                <div className='chat-detail-header-info-item'>
                    <div className='chat-detail-header-info-item-label'>MCN</div>
                    <div className='chat-detail-header-info-item-value'>{selectedCreator?.business?.mcn || '--'}</div>
                </div>
                <div className='chat-detail-header-info-item'>
                    <div className='chat-detail-header-info-item-label'>Pricing</div>
                    <div className='chat-detail-header-info-item-value'>
                        {selectedCreator?.business?.pricing?.price || '--'}
                    </div>
                </div>
                <div className='chat-detail-header-info-item'>
                    <div className='chat-detail-header-info-item-label'>Collab.</div>
                    <div className='chat-detail-header-info-item-value'>
                        {selectedCreator?.business?.latest_collab || '--'}
                    </div>
                </div>
            </div>
            <div className='chat-detail-summary'>
                <div className='chat-detail-summary-title'>Chat Summary</div>
                <Form.Control
                    as='textarea'
                    disabled
                    rows={6}
                    className='chat-detail-summary-input'
                    value={currentChat?.summary?.summary || currentChat?.summary_error || 'No summary available'}
                />
            </div>
            <div className='chat-detail-generate'>
                <div className='chat-detail-generate-title'>Chat Generate</div>
                <Form className='generate-form' onSubmit={handleSubmit}>
                    <Form.Control
                        disabled
                        as='textarea'
                        rows={4}
                        className='generate-input'
                        value={currentChat?.recommended_reply?.reply || currentChat?.recommended_reply_error}
                    />
                    <Button className='rounded-pill submit-btn btn-sm' type='submit'>
                        <LoaderCircle size={16} />
                    </Button>
                </Form>
            </div>
            <div className='chat-detail-send-btn'>
                <Button className='rounded-pill btn-sm' type='submit' onClick={handleSendEmail}>
                    Send
                </Button>
            </div>
        </div>
    );
}
