import StreamingMarkdown from './StreamingMarkdown';
import { Copy, RotateCcw } from 'lucide-react';
import { useState } from 'react';

export default function ChatMessage({ message, isStreaming = false }) {
    const [copied, setCopied] = useState(false);

    const handleCopy = async () => {
        try {
            await navigator.clipboard.writeText(message.content);
            setCopied(true);
            setTimeout(() => setCopied(false), 2000);
        } catch (err) {
            console.error('复制失败:', err);
        }
    };

    const handleRegenerate = () => {
        // 这里可以触发重新生成消息的逻辑
        console.log('重新生成消息:', message.id);
    };

    if (message.role === 'user') {
        return (
            <div className='message user mb-3'>
                <div className='d-flex justify-content-end'>
                    <div className='message-content user-message'>
                        <div className='message-text'>{message.content}</div>
                    </div>
                </div>
            </div>
        );
    }

    return (
        <div className='message assistant mb-3'>
            <StreamingMarkdown content={message.content} isStreaming={isStreaming} typewriterSpeed={20} />

            {/* 消息操作按钮 */}
            {!isStreaming && (
                <div className='message-actions mt-2'>
                    <button className='btn btn-sm btn-outline-primary me-2' onClick={handleCopy} title='复制内容'>
                        <Copy size={14} />
                        {copied && <span className='ms-1'>已复制</span>}
                    </button>
                    <button
                        className='btn btn-sm btn-outline-secondary d-none'
                        onClick={handleRegenerate}
                        title='重新生成'
                    >
                        <RotateCcw size={14} />
                    </button>
                </div>
            )}
        </div>
    );
}
