import { useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { fetchChatHistory } from '../store/slices/inboxSlice';
import { Ellipsis, Send } from 'lucide-react';
import { Button, Form } from 'react-bootstrap';
import ChatInput from './ChatInput';
import ChatMessage from './ChatMessage';

export default function ChatWindow({ onOpenChatDetails }) {
    const { currentChat, status } = useSelector((state) => state.chat);
    const [activePlatform, setActivePlatform] = useState('email');
    const dispatch = useDispatch();
    const [message, setMessage] = useState('');
    const [streamingMessageId, setStreamingMessageId] = useState(null);

    const platformOptions = [
        {
            name: 'Email',
            value: 'email',
        },
        {
            name: 'WhatsApp',
            value: 'whatsapp',
        },
    ];

    const handlePlatformChange = (value) => {
        setActivePlatform(value);
    };

    useEffect(() => {
        if (currentChat) {
            console.log(currentChat);
        }
    }, [currentChat]);

    const handleSendMessage = () => {
        console.log(message);
    };

    return (
        <div className='chat-window'>
            <div className='chat-window-header'>
                <div className='chat-window-header-left'>
                    <div className='chat-window-header-left-avatar'>
                        <img src={currentChat?.negotiation?.creator?.avatar} alt={currentChat?.negotiation?.creator?.name} />
                    </div>
                    <div className='chat-window-header-left-info'>
                        <div className='chat-window-header-left-info-name fw-bold' onClick={onOpenChatDetails}>
                            {currentChat?.negotiation?.creator?.name}
                        </div>
                        <div className='chat-window-header-left-info-product rounded-pill'>
                            {currentChat?.negotiation?.product?.name}
                        </div>
                    </div>
                </div>
                <div className='chat-window-header-right'>
                    <div className='platform-selection'>
                        {platformOptions.map((option) => (
                            <div
                                key={option.value}
                                className={`platform-selection-item ${activePlatform === option.value ? 'active' : ''}`}
                                onClick={() => handlePlatformChange(option.value)}
                            >
                                {option.name}
                            </div>
                        ))}
                    </div>
                    <div className='actions'>
                        <Ellipsis />
                    </div>
                </div>
            </div>
            <div className='chat-window-body'>
                <div className='chat-body'>
                    {currentChat?.messages?.length > 0 &&
                        currentChat?.messages?.map((msg) => (
                            <ChatMessage key={msg.id} message={msg} isStreaming={msg.id === streamingMessageId} />
                        ))}
                </div>
            </div>
            <div className='chat-window-footer'>
                <Form className='footer-input' onSubmit={handleSendMessage}>
                    <ChatInput value={message} onChange={(e) => setMessage(e.target.value)} onSubmit={handleSendMessage} />
                    <Button variant='outline-primary' className='border-0' type='submit'>
                        <Send />
                    </Button>
                </Form>
            </div>
        </div>
    );
}
