import { useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { fetchInboxList } from '../store/slices/inboxSlice';
import { fetchChatDetails, selectChat } from '../store/slices/chatSlice';
import { chatDateFormat } from '../lib/utils.jsx';

export default function InboxList() {
    const dispatch = useDispatch();
    const { inboxList, inboxStatus: status, error } = useSelector((state) => state.inbox);
    const { currentChat } = useSelector((state) => state.chat);
    const [activeToggle, setActiveToggle] = useState('all'); // all or initial_contact or negotiation or follow_up
    const [activeSelect, setActiveSelect] = useState('all'); // all or unread
    const toggleOptions = [
        { name: '全部', value: 'all' },
        { name: '首次建联', value: 'initial_contact' },
        { name: '砍价邮件', value: 'negotiation' },
        { name: '合作追踪', value: 'follow_up' },
    ];

    useEffect(() => {
        if (activeToggle === 'all') {
            dispatch(fetchInboxList({}));
        } else {
            dispatch(fetchInboxList({ status: activeToggle }));
        }
    }, [dispatch, activeToggle]);

    useEffect(() => {
        if (inboxList.length > 0) {
            // dispatch(selectChat(inboxList[0]));
            // dispatch(fetchChatHistory(inboxList[0].id));
        }
    }, [dispatch, inboxList]);

    const handleSelectChat = (item) => {
        dispatch(selectChat(item));
        dispatch(fetchChatDetails({ conversation_id: item.conversation_id }));
    };

    return (
        <div className='inbox-list-container'>
            <div className='breadcrumb'>
                <div className='breadcrumb-item'>Creator Inbox</div>
            </div>

            <div className='list-filter mb-2'>
                <div className='toggle-list'>
                    {toggleOptions.map((option) => (
                        <div
                            key={option.value}
                            className={`toggle-option ${option.value === activeToggle ? 'active' : ''}`}
                            onClick={() => setActiveToggle(option.value)}
                        >
                            {option.name}
                        </div>
                    ))}
                </div>
                <div className='select-list'>
                    <span
                        className={`select-option ${activeSelect === 'all' ? 'active' : ''}`}
                        onClick={() => setActiveSelect('all')}
                    >
                        All
                    </span>
                    <span
                        className={`select-option ${activeSelect === 'unread' ? 'active' : ''}`}
                        onClick={() => setActiveSelect('unread')}
                    >
                        Unread
                    </span>
                </div>
                <div className='actions'>批量</div>
            </div>

            <div className='list-content'>
                {status === 'loading' && <div>Loading...</div>}
                {status === 'failed' && <div>Error: {error}</div>}
                {status === 'succeeded' &&
                    (inboxList.length > 0 ? (
                        inboxList.map((chat) => (
                            <div
                                key={chat.conversation_id}
                                className={`list-item ${
                                    currentChat?.conversation_id === chat.conversation_id ? 'active' : ''
                                }`}
                                onClick={() => handleSelectChat(chat)}
                            >
                                <div className='list-item-left'>
                                    <div className='list-item-left-avatar'>
                                        <img src={chat.creator.avatar} alt={chat.creator.name} />
                                    </div>
                                    <div className='list-item-info'>
                                        <div className='list-name fw-bold'>{chat.creator.name}</div>
                                        <div className='list-message'>{chat.last_message}</div>
                                    </div>
                                </div>
                                <div className='list-item-right'>
                                    <div className='list-item-right-time'>{chatDateFormat(chat.last_time)}</div>
                                    {chat.unread_count > 0 && (
                                        <div className='list-item-right-badge'>{chat.unread_count}</div>
                                    )}
                                </div>
                            </div>
                        ))
                    ) : (
                        <div className='list-item-empty'>No Chats Found</div>
                    ))}
            </div>
        </div>
    );
}
