import { useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { fetchCampaignCreators, fetchProductCampaigns, fetchProductDetail } from '../store/slices/productSlice';
import { mockCreators } from '../store/slices/creatorsSlice';
import { Accordion, Alert, Table } from 'react-bootstrap';
import SpinningComponent from './SpinningComponent';

export default function ProductDetail() {
    const { currentProduct } = useSelector((state) => state.products);
    const dispatch = useDispatch();

    useEffect(() => {
        dispatch(fetchProductDetail(currentProduct.id));
    }, [currentProduct.id]);

    return (
        <div className='product-details shadow-xs'>
            <div className='product-details-header'>
                <div className='product-details-header-title'>{currentProduct.name}</div>
                <div className='product-details-header-pid'>PID: {currentProduct.id}</div>
            </div>
            <div className='product-details-body'>
                <div className='product-img'></div>
                <div className='product-detail-list'>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{currentProduct.commission_rate}</div>
                        <div className='product-detail-item-label'>Commission Rate</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{currentProduct.available_samples}</div>
                        <div className='product-detail-item-label'>Available Samples</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>
                            {currentProduct.sales_price_max} - {currentProduct.sales_price_min}
                        </div>
                        <div className='product-detail-item-label'>Sales Price</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{currentProduct.stock}</div>
                        <div className='product-detail-item-label'>Stock</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{currentProduct.items_sold}</div>
                        <div className='product-detail-item-label'>Items Sold</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{currentProduct.product_rating}</div>
                        <div className='product-detail-item-label'>Product Rating</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{currentProduct.collab_creators}</div>
                        <div className='product-detail-item-label'>Collab Creators</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{currentProduct.gmv}</div>
                        <div className='product-detail-item-label'>GMV Achieved</div>
                    </div>
                    <div className='product-detail-item'>
                        <div className='product-detail-item-value'>{currentProduct.reviews_count}</div>
                        <div className='product-detail-item-label'>Views Achieved</div>
                    </div>
                </div>
            </div>
        </div>
    );
}

export const CampaignsCollabCreators = () => {
    const { currentProduct, status } = useSelector((state) => state.products);
    const dispatch = useDispatch();

    useEffect(() => {
        const fetchCampaigns = async () => {
            await dispatch(fetchProductCampaigns(currentProduct.id)).unwrap();
        };
        fetchCampaigns();
    }, []);

    if (status === 'loading') {
        return <SpinningComponent />;
    }
    if (!currentProduct.campaigns || currentProduct.campaigns.length < 0) {
        return <Alert variant='info'>No campaigns found</Alert>;
    }

    return (
        <Accordion className='campaigns-collab-creators-list' defaultActiveKey={currentProduct.campaigns[0].id}>
            {currentProduct.campaigns.map((item) => (
                <Accordion.Item eventKey={item.id} key={item.id} className='campaigns-collab-creators-item'>
                    <Accordion.Header>{item.name}</Accordion.Header>
                    <Accordion.Body>
                        <Table responsive hover className='bg-white shadow-xs rounded overflow-hidden'>
                            <thead>
                                <tr>
                                    <th>Creator</th>
                                    <th>Category</th>
                                    <th>Followers</th>
                                    <th>GMV Generated</th>
                                    <th>Views Generated</th>
                                    <th>Pricing</th>
                                    <th>Status</th>
                                </tr>
                            </thead>
                            <tbody>
                                {item?.creators?.length > 0 ? (
                                    item?.creators.map((creator) => (
                                        <tr key={creator.id}>
                                            <td>
                                                <div className='white-space-nowrap'>
                                                    <img
                                                        className='creator-avatar'
                                                        src={creator.avatar}
                                                        alt={creator.name}
                                                    />
                                                    <span className='creator-name'>{creator.name}</span>
                                                </div>
                                            </td>
                                            <td>{creator.category}</td>
                                            <td>{creator.followers || '--'}</td>
                                            <td>{creator.gmv || '--'}</td>
                                            <td>{creator.views || '--'}</td>
                                            <td>{creator.pricing || '--'}</td>
                                            <td>{creator.status || '--'}</td>
                                        </tr>
                                    ))
                                ) : (
                                    <tr>
                                        <td colSpan={7} className='text-center'>
                                            No creators found
                                        </td>
                                    </tr>
                                )}
                            </tbody>
                        </Table>
                    </Accordion.Body>
                </Accordion.Item>
            ))}
        </Accordion>
    );
};
