import React, { useEffect, useState } from 'react';
import { Table, Form, Button, Modal } from 'react-bootstrap';
import { useSelector, useDispatch } from 'react-redux';
import '../styles/Products.scss';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import Spinning from './SpinningComponent';
import { Plus } from 'lucide-react';
import SpinningComponent from './SpinningComponent';
import { addProductToCampaign } from '../store/slices/productSlice';

export default function ProductsList({ products, onShowProductDetail, type = 'default' }) {
    const { selectedBrand, status } = useSelector((state) => state.brands);
    const [sortField, setSortField] = useState(null);
    const [sortDirection, setSortDirection] = useState('asc');
    const [selectedProducts, setSelectedProducts] = useState([]);
    const [showAddProductToCampaignModal, setShowAddProductToCampaignModal] = useState(false);
    const [selectedProduct, setSelectedProduct] = useState(null);

    const handleSort = (field) => {
        return;
        if (sortField === field) {
            setSortDirection(sortDirection === 'asc' ? 'desc' : 'asc');
        } else {
            setSortField(field);
            setSortDirection('asc');
        }
    };

    const renderSortIcon = (field) => {
        return;
        if (sortField !== field) return null;
        return sortDirection === 'asc' ? '↑' : '↓';
    };

    const handleSelectAll = (e) => {
        if (e.target.checked) {
            setSelectedProducts(products.map((product) => product.id));
        } else {
            setSelectedProducts([]);
        }
    };

    const handleSelectProduct = (productId) => {
        if (selectedProducts.includes(productId)) {
            setSelectedProducts(selectedProducts.filter((id) => id !== productId));
        } else {
            setSelectedProducts([...selectedProducts, productId]);
        }
    };

    if (status === 'loading') {
        return <SpinningComponent />;
    }

    return (
        <div className='products-list rounded shadow-xs'>
            <Table responsive hover className='bg-white rounded overflow-hidden m-0'>
                <thead>
                    <tr>
                        <th className='selector' style={{ width: '40px' }}>
                            <Form.Check
                                type='checkbox'
                                checked={selectedProducts.length === products?.length && products?.length > 0}
                                onChange={handleSelectAll}
                            />
                        </th>
                        <th className='product' onClick={() => handleSort('name')}>
                            Product {renderSortIcon('name')}
                        </th>
                        <th className='commission text-center' onClick={() => handleSort('commission')}>
                            Commission Rate {renderSortIcon('commission')}
                        </th>
                        <th className='samples text-center' onClick={() => handleSort('availableSamples')}>
                            Available Samples {renderSortIcon('availableSamples')}
                        </th>
                        <th className='price text-center' onClick={() => handleSort('price')}>
                            Sales Price {renderSortIcon('price')}
                        </th>
                        <th className='stock text-center' onClick={() => handleSort('stock')}>
                            Stock {renderSortIcon('stock')}
                        </th>
                        <th className='sold text-center' onClick={() => handleSort('sold')}>
                            Items Sold {renderSortIcon('sold')}
                        </th>
                        <th className='rating text-center' onClick={() => handleSort('rating')}>
                            Product Rating {renderSortIcon('rating')}
                        </th>
                        <th className='creators text-center' onClick={() => handleSort('collabCreators')}>
                            Collab. Creators {renderSortIcon('collabCreators')}
                        </th>
                        <th className='tiktokShop text-center' onClick={() => handleSort('tiktokShop')}>
                            TikTok Shop {renderSortIcon('tiktokShop')}
                        </th>
                        {type === 'brand' && <th className='actions text-center'>Add To Campaign</th>}
                    </tr>
                </thead>
                <tbody>
                    {products?.length === 0 ? (
                        <tr>
                            <td colSpan='11' className='text-center py-4'>
                                No products found for this brand.
                            </td>
                        </tr>
                    ) : (
                        products?.map((product) => (
                            <tr key={product.id} className={selectedProducts.includes(product.id) ? 'selected' : ''}>
                                <td>
                                    <Form.Check
                                        type='checkbox'
                                        checked={selectedProducts.includes(product.id)}
                                        onChange={() => handleSelectProduct(product.id)}
                                    />
                                </td>
                                <td className='product-cell'>
                                    <div
                                        className='d-flex align-items-center'
                                        onClick={() => onShowProductDetail(product)}
                                        style={{ cursor: 'pointer' }}
                                    >
                                        <img className='product-logo' src={product.image_url} alt={product.name} />
                                        {/* <div className='product-logo'>{product.name.slice(0, 1)}</div> */}
                                        <div className='product-name'>{product.name}</div>
                                    </div>
                                </td>
                                <td className='text-center'>
                                    <div>{product.commission_rate}</div>
                                    <div className='small text-muted'>Open collab. {product.open_collab}</div>
                                </td>
                                <td className='text-center'>{product.available_samples}</td>
                                <td className='text-center'>
                                    {product.sales_price_min} - {product.sales_price_max}
                                </td>
                                <td className='text-center'>{product.stock}</td>
                                <td className='text-center'>{product.items_sold}</td>
                                <td className='text-center'>
                                    <div>{product.product_rating}</div>
                                    <div className='small text-muted'>{product.reviews_count} Reviews</div>
                                </td>
                                <td className='text-center'>{product.collab_creators}</td>
                                <td className='text-center'>
                                    {product.tiktok_shop && <FontAwesomeIcon icon='fa-brands fa-tiktok' />}
                                </td>
                                {type === 'brand' && (
                                    <td className='text-center'>
                                        <button className='border-0 bg-transparent text-primary' onClick={() => {
                                            setSelectedProduct(product.id);
                                            setShowAddProductToCampaignModal(true);
                                        }}>
                                            <Plus />
                                        </button>
                                    </td>
                                )}
                            </tr>
                        ))
                    )}
                </tbody>
            </Table>
            <AddProductToCampaignModal show={showAddProductToCampaignModal} onHide={() => setShowAddProductToCampaignModal(false)} productId={selectedProduct} />
        </div>
    );
}

function AddProductToCampaignModal({ show, onHide, productId }) {
    const [campaignId, setCampaignId] = useState(null);
    const { selectedBrand } = useSelector((state) => state.brands);
    const dispatch = useDispatch();
    
    const handleSubmit = async (e) => {
        e.preventDefault();
        console.log(campaignId, productId);
        await dispatch(addProductToCampaign({ campaignId, productId })).unwrap();
        handleCancel();
    };

    const handleCancel = () => {
        setCampaignId(null);
        onHide();
    };

    return (
        <Modal show={show} onHide={onHide} size='md'>
            <Modal.Header closeButton className='fw-bold'>
                Add Product
            </Modal.Header>
            <Form onSubmit={handleSubmit}>
                <Modal.Body>
                    <Form.Group>
                        <Form.Label>Campaign Name</Form.Label>
                        <Form.Select required value={campaignId} onChange={(e) => setCampaignId(e.target.value)}>
                            <option value=''>Select Campaign</option>
                            {selectedBrand?.campaigns?.map((campaign) => (
                                <option key={campaign.id} value={campaign.id}>
                                    {campaign.name}
                                </option>
                            ))}
                        </Form.Select>
                    </Form.Group>
                </Modal.Body>
                <Modal.Footer>
                    <Button variant='outline-primary' className='border-0' onClick={handleCancel}>
                        Cancel
                    </Button>
                    <Button variant='primary' type='submit'>
                        Add
                    </Button>
                </Modal.Footer>
            </Form>
        </Modal>
    );
}
