import React, { useState } from 'react';
import { Button, Form } from 'react-bootstrap';
import SlidePanel from './SlidePanel';

const SlidePanelExample = () => {
    const [showPanel, setShowPanel] = useState(false);
    const [placement, setPlacement] = useState('end');
    const [size, setSize] = useState('md');

    const handleOpen = () => setShowPanel(true);
    const handleClose = () => setShowPanel(false);

    // Example content for the panel
    const exampleContent = (
        <div>
            <p>This is an example of the SlidePanel component. You can place any content here.</p>
            <Form>
                <Form.Group className='mb-3'>
                    <Form.Label>Example input</Form.Label>
                    <Form.Control type='text' placeholder='Enter text' />
                </Form.Group>
                <Form.Group className='mb-3'>
                    <Form.Label>Example select</Form.Label>
                    <Form.Select>
                        <option>Option 1</option>
                        <option>Option 2</option>
                        <option>Option 3</option>
                    </Form.Select>
                </Form.Group>
                <Button variant='primary'>Submit</Button>
            </Form>
        </div>
    );

    return (
        <div>
            <div className='mb-3'>
                <h5>Panel Position</h5>
                <div className='d-flex gap-2'>
                    <Button
                        variant={placement === 'start' ? 'primary' : 'outline-primary'}
                        onClick={() => setPlacement('start')}
                    >
                        Left
                    </Button>
                    <Button
                        variant={placement === 'end' ? 'primary' : 'outline-primary'}
                        onClick={() => setPlacement('end')}
                    >
                        Right
                    </Button>
                    <Button
                        variant={placement === 'top' ? 'primary' : 'outline-primary'}
                        onClick={() => setPlacement('top')}
                    >
                        Top
                    </Button>
                    <Button
                        variant={placement === 'bottom' ? 'primary' : 'outline-primary'}
                        onClick={() => setPlacement('bottom')}
                    >
                        Bottom
                    </Button>
                </div>
            </div>

            <div className='mb-3'>
                <h5>Panel Size</h5>
                <div className='d-flex gap-2'>
                    <Button variant={size === 'sm' ? 'primary' : 'outline-primary'} onClick={() => setSize('sm')}>
                        Small
                    </Button>
                    <Button variant={size === 'md' ? 'primary' : 'outline-primary'} onClick={() => setSize('md')}>
                        Medium
                    </Button>
                    <Button variant={size === 'lg' ? 'primary' : 'outline-primary'} onClick={() => setSize('lg')}>
                        Large
                    </Button>
                </div>
            </div>

            <Button variant='success' onClick={handleOpen}>
                Open SlidePanel
            </Button>

            <SlidePanel
                show={showPanel}
                onClose={handleClose}
                title='SlidePanel Example'
                placement={placement}
                size={size}
            >
                {exampleContent}
            </SlidePanel>
        </div>
    );
};

export default SlidePanelExample;
