import ReactMarkdown from 'react-markdown';
import remarkGfm from 'remark-gfm';
import { Prism as SyntaxHighlighter } from 'react-syntax-highlighter';
import { tomorrow } from 'react-syntax-highlighter/dist/esm/styles/prism';
import { useTypewriter } from '../hooks/useTypewriter';

export default function StreamingMarkdown({ content, isStreaming = z, typewriterSpeed = 30 }) {
    const { displayText, isTyping, skipAnimation } = useTypewriter(isStreaming ? content : '', typewriterSpeed);

    // 如果不是流式模式，直接显示完整内容
    const textToRender = isStreaming ? displayText : content;

    return (
        <div className='streaming-markdown'>
            <ReactMarkdown
                remarkPlugins={[remarkGfm]}
                components={{
                    code({ node, inline, className, children, ...props }) {
                        const match = /language-(\w+)/.exec(className || '');
                        return !inline && match ? (
                            <SyntaxHighlighter style={tomorrow} language={match[1]} PreTag='div' {...props}>
                                {String(children).replace(/\n$/, '')}
                            </SyntaxHighlighter>
                        ) : (
                            <code className={className} {...props}>
                                {children}
                            </code>
                        );
                    },
                    // 自定义表格样式
                    table({ children }) {
                        return (
                            <div className='table-responsive'>
                                <table className='table table-striped table-hover'>{children}</table>
                            </div>
                        );
                    },
                    // 自定义链接样式
                    a({ href, children }) {
                        return (
                            <a href={href} target='_blank' rel='noopener noreferrer' className='text-decoration-none'>
                                {children}
                            </a>
                        );
                    },
                }}
            >
                {textToRender}
            </ReactMarkdown>

            {/* 打字机效果控制 */}
            {isStreaming && isTyping && (
                <div className='typewriter-controls mt-2'>
                    <button className='btn btn-sm btn-outline-secondary' onClick={skipAnimation}>
                        跳过动画
                    </button>
                </div>
            )}
        </div>
    );
}
