import { useState, useEffect, useRef } from 'react';

export const useTypewriter = (text, speed = 30) => {
    const [displayText, setDisplayText] = useState('');
    const [isTyping, setIsTyping] = useState(false);
    const [isCompleted, setIsCompleted] = useState(false);
    const intervalRef = useRef(null);
    const indexRef = useRef(0);

    useEffect(() => {
        if (!text) return;

        setDisplayText('');
        setIsTyping(true);
        setIsCompleted(false);
        indexRef.current = 0;

        intervalRef.current = setInterval(() => {
            setDisplayText((prev) => {
                const newText = text.slice(0, indexRef.current + 1);
                indexRef.current++;

                if (indexRef.current >= text.length) {
                    setIsTyping(false);
                    setIsCompleted(true);
                    clearInterval(intervalRef.current);
                }

                return newText;
            });
        }, speed);

        return () => {
            if (intervalRef.current) {
                clearInterval(intervalRef.current);
            }
        };
    }, [text, speed]);

    const skipAnimation = () => {
        if (intervalRef.current) {
            clearInterval(intervalRef.current);
        }
        setDisplayText(text);
        setIsTyping(false);
        setIsCompleted(true);
    };

    return {
        displayText,
        isTyping,
        isCompleted,
        skipAnimation,
    };
};
