import React, { useEffect, useState } from 'react';
import BrandsList from '../components/BrandsList';
import SearchBar from '../components/SearchBar';
import { Button, Modal, Form } from 'react-bootstrap';
import '../styles/Brands.scss';
import { useNavigate } from 'react-router-dom';
import { Plus } from 'lucide-react';
import { useDispatch, useSelector } from 'react-redux';
import { createBrandThunk, fetchBrands, searchBrands, selectBrand } from '../store/slices/brandsSlice';
import SpinningComponent from '../components/SpinningComponent';
import { BRAND_SOURCES } from '../lib/constant';

export default function Brands() {
    const navigate = useNavigate();
    const dispatch = useDispatch();
    const [showAddBrandModal, setShowAddBrandModal] = useState(false);
    const [searchValue, setSearchValue] = useState('');

    useEffect(() => {}, [dispatch]);

    const openBrandDetail = async (item) => {
        await dispatch(selectBrand(item));
        navigate(`/brands/${item.id}`);
    };

    const handleSearch = (e) => {
        e.preventDefault();
        dispatch(searchBrands({ keyword: searchValue }));
    };

    return (
        <React.Fragment>
            <div className='function-bar'>
                <SearchBar onSearch={handleSearch} value={searchValue} onChange={(e) => setSearchValue(e.target.value)} />
                <Button onClick={() => setShowAddBrandModal(true)}>
                    <Plus />
                    Add Brand
                </Button>
            </div>
            <div className='breadcrumb'>
                <div className='breadcrumb-item'>Brands</div>
            </div>
            <BrandsList openBrandDetail={openBrandDetail} />
            <AddBrandModal show={showAddBrandModal} onHide={() => setShowAddBrandModal(false)} />
        </React.Fragment>
    );
}

function AddBrandModal({ show, onHide }) {
    const [brandName, setBrandName] = useState('');
    const [brandSource, setBrandSource] = useState('');
    const [campaignId, setCampaignId] = useState('');
    const [validated, setValidated] = useState(false);
    const dispatch = useDispatch();
    const { status, error } = useSelector((state) => state.brands);

    const handleSubmit = async (e) => {
        const form = document.getElementById('brandForm');
        if (form.checkValidity() === false) {
            e.preventDefault();
            e.stopPropagation();
            setValidated(true);
            return;
        }
        const brand = {
            name: brandName,
            source: brandSource,
            campaign_id: campaignId,
        };
        await dispatch(createBrandThunk(brand)).unwrap();
        if (status === 'succeeded') {
            dispatch(fetchBrands());
            handleCancel();
        }
    };

    const handleCancel = () => {
        onHide();
        setBrandName('');
        setBrandSource('');
        setCampaignId('');
    };

    if (show && status === 'loading') {
        return <SpinningComponent />;
    }

    return (
        <Modal show={show} onHide={onHide} backdropClassName='modal-backdrop' container={document.body}>
            <Modal.Header>
                <Modal.Title>Add Brand</Modal.Title>
            </Modal.Header>
            <Modal.Body>
                <Form
                    id='brandForm'
                    noValidate
                    validated={validated}
                    onSubmit={handleSubmit}
                    className='add-brand-form'
                >
                    <Form.Group className='mb-3' controlId='formBasicName'>
                        <Form.Label>BrandName</Form.Label>
                        <Form.Control
                            type='text'
                            required
                            placeholder='Enter name'
                            value={brandName}
                            onChange={(e) => setBrandName(e.target.value)}
                        />
                    </Form.Group>
                    <Form.Group className='mb-3' controlId='formBasicSource'>
                        <Form.Label>Source</Form.Label>
                        <Form.Select value={brandSource} onChange={(e) => setBrandSource(e.target.value)} required>
                            {BRAND_SOURCES.map((option) => (
                                <option key={option.value} value={option.value}>
                                    {option.name}
                                </option>
                            ))}
                        </Form.Select>
                    </Form.Group>
                    <Form.Group className='mb-3' controlId='formBasicCampaignId'>
                        <Form.Label>Campaign ID</Form.Label>
                        <Form.Text className='text-muted'>
                            这个活动ID没必要在新增品牌的时候添加吧？
                        </Form.Text>
                        <Form.Control
                            type='text'
                            required
                            placeholder='Enter campaign ID'
                            value={campaignId}
                            onChange={(e) => setCampaignId(e.target.value)}
                        />
                    </Form.Group>
                    <div className='button-group'>
                        <Button variant='outline-light' className='text-primary' onClick={handleCancel}>
                            Cancel
                        </Button>
                        <Button variant='primary' onClick={handleSubmit}>
                            Create
                        </Button>
                    </div>
                </Form>
            </Modal.Body>
        </Modal>
    );
}
