import { useDispatch, useSelector } from 'react-redux';
import { useCallback, useEffect, useState } from 'react';
import {  Button, Card, Col, Form, Row } from 'react-bootstrap';
import { CloudUpload, Paperclip } from 'lucide-react';
import { useDropzone } from 'react-dropzone';
import ProductDetail, { CampaignsCollabCreators } from '../components/ProductDetail';

export default function CampaignScript() {
    const dispatch = useDispatch();
    const { currentProduct } = useSelector((state) => state.products);
    const [activeTab, setActiveTab] = useState('collaborationInfo');

    useEffect(() => {
        console.log(currentProduct);
    }, [currentProduct]);

    return (
        currentProduct?.id && (
            <div className='product-script'>
                <ProductDetail />
                <div className='product-script-switches tab-switches'>
                    <div
                        className={`tab-switch-item ${activeTab === 'collaborationInfo' ? 'active' : ''}`}
                        onClick={() => setActiveTab('collaborationInfo')}
                    >
                        Collaboration Info
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'campaigns' ? 'active' : ''}`}
                        onClick={() => setActiveTab('campaigns')}
                    >
                        Campaigns & Collaborated Creators
                    </div>
                </div>
                {activeTab === 'collaborationInfo' && <CollabInfo />}
                {activeTab === 'campaigns' && <CampaignsCollabCreators />}
            </div>
        )
    );
}
const CollabInfo = () => {
    const [formData, setFormData] = useState({
        productSellingPoint: '吸力强、有效除菌、香薰片功能、价格更优惠、两种颜色',
        exampleVideos: 'https://mcnmza4kafoj.feishu.cn/drive/folder/HzhWfGvWtlCBqIduwfLczQ9Cnyb',
        videoPostingSuggestion: '开头引人+产品亮点+CTA呼吁/时长30~50s左右',
        videoAcceptanceStandard: `1.场景：包括不限于厨房、卫生间、衣柜；在橱柜下方和洗手台下方安装橱柜灯、衣柜等安全及方便需求。场景展示要有黑暗环境对比HOOK。
        2.红人必须要表达卖点（以下卖点按优先级排列，达人任意选择提到至少三个卖点即可）
        电池大续航能力强可以（必须提到）（可用字幕展示）
        容易安装（有磁铁）（必须提到）（要拍出安装过程）
        开启人体感应模式 （必须提到）（可视觉展示）
        可充电
        亮度高，且可调节
        加分卖点：
        视频需说明购买理由以及使用感受（例如：老人家晚上更安全，宝妈晚上起床更便捷安全等等购买理由）
        3.正确的hashtags 以及正确@官方账号`,
        documentsUpload: [],
    });

    const handleChange = (e) => {
        setFormData({ ...formData, [e.target.name]: e.target.value });
    };

    return (
        <Card className='product-script-video-req'>
            <Form className='video-req-form'>
                <div className='form-header'>Video Posting Requirement</div>
                <Form.Group>
                    <Form.Label>Product Selling Point</Form.Label>
                    <Form.Control
                        type='textarea'
                        as='textarea'
                        rows={3}
                        placeholder='Enter the product selling point'
                        name='productSellingPoint'
                        value={formData.productSellingPoint}
                        onChange={handleChange}
                    />
                </Form.Group>
                <Form.Group>
                    <Form.Label>Example Videos</Form.Label>
                    <Form.Control
                        type='textarea'
                        as='textarea'
                        rows={3}
                        placeholder='Enter the example videos'
                        name='exampleVideos'
                        value={formData.exampleVideos}
                        onChange={handleChange}
                    />
                </Form.Group>
                <Form.Group>
                    <Form.Label>Video Posting Suggestion</Form.Label>
                    <Form.Control
                        type='textarea'
                        as='textarea'
                        rows={3}
                        placeholder='Enter the video posting suggestion'
                        name='videoPostingSuggestion'
                        value={formData.videoPostingSuggestion}
                        onChange={handleChange}
                    />
                </Form.Group>
                <Form.Group>
                    <Form.Label>Video Acceptance Standard</Form.Label>
                    <Form.Control
                        type='textarea'
                        as='textarea'
                        rows={3}
                        placeholder='Enter the video acceptance standard'
                        name='videoAcceptanceStandard'
                        value={formData.videoAcceptanceStandard}
                        onChange={handleChange}
                    />
                </Form.Group>
                <Form.Group className='upload-group'>
                    <FileUpload />
                </Form.Group>
            </Form>
            <div className='product-ai-script'>
                <div className='header'>
                    <div className='title'>Script</div>
                    <Button variant='primary' className='generate-btn'>
                        AI Generate
                    </Button>
                </div>
                <Form className='script-versions'>
                    <Form.Group>
                        <Form.Label>Version 1</Form.Label>
                        <Form.Control type='textarea' as='textarea' rows={4} />
                    </Form.Group>
                    <Form.Group>
                        <Form.Label>Version 2</Form.Label>
                        <Form.Control type='textarea' as='textarea' rows={4} />
                    </Form.Group>
                </Form>
            </div>
        </Card>
    );
};

const FileUpload = () => {
    const [files, setFiles] = useState([]);

    const onDrop = useCallback((acceptedFiles) => {
        setFiles((prev) => [...prev, ...acceptedFiles]);
    }, []);

    const { getRootProps, getInputProps, isDragActive } = useDropzone({
        onDrop,
        accept: {
            'application/pdf': [],
            'application/vnd.openxmlformats-officedocument.wordprocessingml.document': [],
            'image/png': [],
            'image/jpeg': [],
            'text/csv': [],
            'application/vnd.openxmlformats-officedocument.presentationml.presentation': [],
        },
    });

    const renderFileIcon = (file) => {
        if (file.name.endsWith('.pdf')) return <FaFilePdf size={24} color='#6366f1' className='me-2' />;
        if (file.name.endsWith('.docx')) return <FaFileWord size={24} color='#6366f1' className='me-2' />;
        return <Paperclip />;
    };

    return (
        <Row>
            <Col md={6}>
                <div className='form-label'>Documents Upload</div>
                <div
                    {...getRootProps()}
                    style={{
                        border: '2px dashed #BCC1CAFF',
                        textAlign: 'center',
                        padding: '24px',
                        cursor: 'pointer',
                        borderRadius: '10px',
                    }}
                >
                    <input {...getInputProps()} />
                    <div className='d-flex flex-column align-items-center gap-1'>
                        <CloudUpload size={60} color='#6E7787FF' />
                        <strong>Drop files here</strong>
                        <p className='text-muted m-0'>Supported format: PNG, JPG, CSV, PDF, DOCX, PPTX</p>
                        <p className='text-muted fw-bold m-0'>OR</p>
                        <span style={{ color: '#6366f1', textDecoration: 'underline' }}>Browse files</span>
                    </div>
                </div>
            </Col>

            <Col md={6}>
                <div className='form-label'>Uploaded Files</div>
                {files.length === 0 && <div className='text-muted'>No files uploaded.</div>}
                {files.map((file, index) => (
                    <div key={index} className='d-flex align-items-center my-2'>
                        {renderFileIcon(file)}
                        <a
                            href={URL.createObjectURL(file)}
                            target='_blank'
                            rel='noreferrer'
                            className='text-primary text-decoration-none'
                        >
                            {file.name}
                        </a>
                    </div>
                ))}
            </Col>
        </Row>
    );
};
