import { ArrowLeft, Crown, Eye, Heart, Instagram, Link, Mail, MapPin } from 'lucide-react';
import { useEffect, useState } from 'react';
import { Card, Table } from 'react-bootstrap';
import { useDispatch, useSelector } from 'react-redux';
import { Link as RouterLink, useNavigate, useParams } from 'react-router-dom';
import {
    clearCreator,
    fetchCreatorDetail,
    fetchCreatorFollowers,
    fetchCreatorMetrics,
    fetchCreatorTrends,
    fetchCreatorVideos,
} from '../store/slices/creatorsSlice';
import { Bar, Doughnut, Line } from 'react-chartjs-2';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

const options = {
    plugins: {
        legend: {
            display: true,
            position: 'right',
            align: 'end',
            labels: {
                usePointStyle: true,
                pointStyle: 'circle',
                boxWidth: 10,
                padding: 10,
                font: {
                    size: 14,
                },
                color: '#eee',
                generateLabels: (chart) => {
                    const dataset = chart.data.datasets[0];
                    return chart.data.labels.map((label, i) => ({
                        text: `${label}  ${dataset.data[i]}%`,
                        fillStyle: dataset.backgroundColor[i],
                        strokeStyle: dataset.backgroundColor[i],
                        fontColor: '#000',
                        lineWidth: 0,
                    }));
                },
            },
        },
        tooltip: {
            callbacks: {
                label: (context) => `${context.label}: ${context.raw}%`,
            },
        },
    },
};

export default function CreatorDetail({}) {
    const { id } = useParams();
    const navigate = useNavigate();
    const dispatch = useDispatch();
    const { selectedCreator, status } = useSelector((state) => state.creators);
    const [activeTab, setActiveTab] = useState('basic');

    const handleBack = () => {
        navigate(-1);
    };

    useEffect(() => {
        dispatch(fetchCreatorDetail({ creatorId: id }));
        fetchCreatorBaisInfo();
        return () => {
            dispatch(clearCreator());
        };
    }, [dispatch, id]);

    const fetchCreatorBaisInfo = () => {
        dispatch(fetchCreatorMetrics({ creatorId: id }));
        dispatch(fetchCreatorFollowers({ creatorId: id }));
        dispatch(fetchCreatorTrends({ creatorId: id }));
        dispatch(fetchCreatorVideos({ creatorId: id }));
    };
    const processChartData = (data, chart) => {
        if (!data) return;
        switch (chart) {
            case 'channel':
                return {
                    labels: Object.keys(data),
                    datasets: [
                        {
                            label: 'GMV',
                            data: Object.values(data),
                            backgroundColor: [
                                'rgba(217, 107, 139)',
                                'rgba(101, 105, 225)',
                                'rgba(93, 200, 179)',
                                'rgba(122, 87, 218)',
                            ],
                        },
                    ],
                };
            case 'category':
                return {
                    labels: Object.keys(data),
                    datasets: [
                        {
                            label: 'Sold',
                            data: Object.values(data),
                            backgroundColor: [
                                'rgba(217, 107, 139)',
                                'rgba(101, 105, 225)',
                                'rgba(93, 200, 179)',
                                'rgba(122, 87, 218)',
                            ],
                        },
                    ],
                };
        }
    };
    if (status === 'loading') {
        return <div>Loading...</div>;
    }
    if (status === 'failed') {
        return <div>Failed to load creator detail</div>;
    }

    if (!selectedCreator) {
        return <div>No creator found</div>;
    }

    return (
        <div className='creator-detail-page'>
            <div className='back-button' onClick={handleBack}>
                <ArrowLeft size={16} /> Go back
            </div>
            {selectedCreator ? (
                <div className='creator-info-detail-container'>
                    <div className='creator-info-container card'>
                        <div className='creator-info-1'>
                            <div className='creator-avatar'>
                                <img src={selectedCreator.creator.avatar} alt={selectedCreator.creator.name} />
                            </div>
                            <div className='creator-info-right'>
                                <div className='creator-name'>{selectedCreator.creator.name}</div>
                                <div className='creator-desc'>{selectedCreator?.description || '--'}</div>
                                <div className='creator-category'>{selectedCreator.business?.category || '--'}</div>
                                <div className='creator-location'>
                                    <MapPin size={16} />
                                    {selectedCreator.creator.location || ' --'}
                                </div>
                                <div className='creator-live-time'>{selectedCreator.live_schedule || '--'}</div>
                            </div>
                        </div>
                        <div className='creator-info-2'>
                            <div className='creator-info-item category-info'>
                                <div className='creator-info-label'>Category</div>
                                <div className='creator-info-value'>
                                    {selectedCreator.business?.categories.map((item, index) => (
                                        <span className='category-item badge' key={index}>
                                            {item}
                                        </span>
                                    ))}
                                </div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label'>MCN</div>
                                <div className='creator-info-value'>{selectedCreator.business?.mcn || '--'}</div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label'>Pricing</div>
                                <div className='creator-info-value'>
                                    {selectedCreator.business?.pricing?.range || '--'}
                                </div>
                            </div>
                            <div className='creator-info-item collab-info'>
                                <div className='creator-info-label'>Collab.</div>
                                <div className='creator-info-value'>
                                    <span className='collab-count'>
                                        {selectedCreator.business?.collab_count || '--'}
                                    </span>
                                    <span className='latest-collab badge'>
                                        {selectedCreator.business?.latest_collab || '--'}
                                    </span>
                                </div>
                            </div>
                        </div>
                        <div className='creator-info-3'>
                            <div className='creator-info-item'>
                                <div className='creator-info-label mail'>
                                    <Mail size={18} />
                                </div>
                                <div className='creator-info-value'>{selectedCreator.creator.email || '--'}</div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label social'>
                                    <Instagram size={18} />
                                </div>
                                <div className='creator-info-value'>
                                    {selectedCreator.creator.social_accounts?.instagram || '--'}
                                </div>
                            </div>
                            <div className='creator-info-item'>
                                <div className='creator-info-label link'>
                                    <Link size={18} />
                                </div>
                                <div className='creator-info-value'>
                                    {selectedCreator.creator.social_accounts?.tiktok || '--'}
                                </div>
                            </div>
                        </div>
                    </div>
                    <div className='creator-data card'>
                        <div className='levels'>
                            <div className='level-item'>
                                <div className='name'>E-commerce Level</div>
                                <div className='value'>{selectedCreator?.metrics?.e_commerce_level || '--'}</div>
                            </div>
                            <div className='level-item'>
                                <div className='name'>Exposure Level</div>
                                <div className='value'>{selectedCreator?.metrics?.exposure_level || '--'}</div>
                            </div>
                        </div>
                        <div className='data-cards'>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator?.metrics?.followers || '--'}</div>
                                <div className='name'>Followers</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator?.metrics?.gmv || '--'}</div>
                                <div className='name'>GMV</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator?.metrics?.avg_video_views || '--'}</div>
                                <div className='name'>Avg Video Views</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator?.metrics?.items_sold || '--'}</div>
                                <div className='name'>Items Sold</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator?.metrics?.gpm || '--'}</div>
                                <div className='name'>GPM</div>
                            </div>
                            <div className='data-card'>
                                <div className='value'>{selectedCreator?.metrics?.gmv_per_customer || '--'}</div>
                                <div className='name'>GMV per customer</div>
                            </div>
                        </div>
                        <div className='data-charts'>
                            <div className='data-chart'>
                                <div className='chart-title'>GMV per sales channel</div>
                                {selectedCreator?.analytics?.gmv_by_channel && (
                                    <Doughnut
                                        data={processChartData(selectedCreator?.analytics?.gmv_by_channel, 'channel')}
                                        options={{ ...options, cutout: 50 }}
                                    />
                                )}
                            </div>
                            <div className='data-chart'>
                                <div className='chart-title'>GMV by product category</div>
                                {selectedCreator?.analytics?.gmv_by_category && (
                                    <Doughnut
                                        data={processChartData(selectedCreator?.analytics?.gmv_by_category, 'category')}
                                        options={{ ...options, cutout: 50 }}
                                    />
                                )}
                            </div>
                        </div>
                    </div>
                    <div className='creator-detail-tab-switches tab-switches'>
                        <div
                            className={`tab-switch-item ${activeTab === 'basic' ? 'active' : ''}`}
                            onClick={() => setActiveTab('basic')}
                        >
                            Basic Info
                        </div>
                        <div
                            className={`tab-switch-item ${activeTab === 'deepAnalysis' ? 'active' : ''}`}
                            onClick={() => setActiveTab('deepAnalysis')}
                        >
                            Deep Analysis
                        </div>
                        <div
                            className={`tab-switch-item ${activeTab === 'collab' ? 'active' : ''}`}
                            onClick={() => setActiveTab('collab')}
                        >
                            Collaboration Info
                        </div>
                    </div>
                    {activeTab === 'basic' && <CreatorBasicInfo selectedCreator={selectedCreator} />}
                    {activeTab === 'collab' && <CollabInfo selectedCreator={selectedCreator} />}
                </div>
            ) : (
                <div>No creator found</div>
            )}
        </div>
    );
}

function CreatorBasicInfo({ selectedCreator }) {
    useEffect(() => {}, [selectedCreator]);
    return (
        <div className='creator-basic-info card'>
            <div className='basic-info-list'>
                <div className='basic-info-title'>Collaboration Metrics</div>
                <div className='basic-info-item'>
                    <div className='value'>
                        {selectedCreator?.metricsData?.collaboration_metrics?.avg_commission_rate || '--'}
                    </div>
                    <div className='name'>Avg. Commission Rate</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>
                        {selectedCreator?.metricsData?.collaboration_metrics?.products_count || '--'}
                    </div>
                    <div className='name'>Products</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>
                        {selectedCreator?.metricsData?.collaboration_metrics?.brand_collaborations || '--'}
                    </div>
                    <div className='name'>Brand Collaborations</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>
                        {selectedCreator?.metricsData?.collaboration_metrics?.product_price || '--'}
                    </div>
                    <div className='name'>Product Price</div>
                </div>
            </div>
            <div className='basic-info-list'>
                <div className='basic-info-title'>
                    Video<span className='time-range'>{selectedCreator?.metricsData?.video?.date_range || '--'}</span>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.video?.gpm || '--'}</div>
                    <div className='name'>Video GPM</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.video?.videos_count || '--'}</div>
                    <div className='name'>Videos</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.video?.avg_views || '--'}</div>
                    <div className='name'>Avg. Video Views</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.video?.avg_engagement || '--'}</div>
                    <div className='name'>Avg. Video Engagement</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.video?.avg_likes || '--'}</div>
                    <div className='name'>Avg. Video Likes</div>
                </div>
            </div>
            <div className='basic-info-list'>
                <div className='basic-info-title'>
                    Shoppable Video
                    <span className='time-range'>
                        {selectedCreator?.metricsData?.shoppable_video?.date_range || '--'}
                    </span>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.shoppable_video?.gpm || '--'}</div>
                    <div className='name'>Video GPM</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.shoppable_video?.videos_count || '--'}</div>
                    <div className='name'>Videos</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.shoppable_video?.avg_views || '--'}</div>
                    <div className='name'>Avg. Video Views</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.shoppable_video?.avg_engagement || '--'}</div>
                    <div className='name'>Avg. Video Engagement</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.shoppable_video?.avg_likes || '--'}</div>
                    <div className='name'>Avg. Video Likes</div>
                </div>
            </div>
            <div className='basic-info-list'>
                <div className='basic-info-title'>
                    LIVE<span className='time-range'>{selectedCreator?.metricsData?.live?.date_range || '--'}</span>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.live?.gpm || '--'}</div>
                    <div className='name'>LIVE GPM</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.live?.lives_count || '--'}</div>
                    <div className='name'>LIVE Videos</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.live?.avg_views || '--'}</div>
                    <div className='name'>Avg. LIVE Views</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.live?.avg_engagement || '--'}</div>
                    <div className='name'>Avg. LIVE Engagement</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.live?.avg_likes || '--'}</div>
                    <div className='name'>Avg. LIVE Likes</div>
                </div>
            </div>
            <div className='basic-info-list'>
                <div className='basic-info-title'>
                    Shoppable LIVE
                    <span className='time-range'>
                        {selectedCreator?.metricsData?.shoppable_live?.date_range || '--'}
                    </span>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.shoppable_live?.gpm || '--'}</div>
                    <div className='name'>LIVE GPM</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.shoppable_live?.lives_count || '--'}</div>
                    <div className='name'>LIVE Videos</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.shoppable_live?.avg_views || '--'}</div>
                    <div className='name'>Avg. LIVE Views</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.shoppable_live?.avg_engagement || '--'}</div>
                    <div className='name'>Avg. LIVE Engagement</div>
                </div>
                <div className='basic-info-item'>
                    <div className='value'>{selectedCreator?.metricsData?.shoppable_live?.avg_likes || '--'}</div>
                    <div className='name'>Avg. LIVE Likes</div>
                </div>
            </div>
            {selectedCreator?.followerData && <CreatorFollowerInfo selectedCreator={selectedCreator} />}
            {selectedCreator?.trendsData && <CreatorTrends selectedCreator={selectedCreator} />}
            {selectedCreator?.videosData && <CreatorVideos selectedCreator={selectedCreator} />}
        </div>
    );
}

function CreatorFollowerInfo({ selectedCreator }) {
    const barOptions = {
        plugins: {
            legend: { display: false },
            tooltip: {
                callbacks: {
                    label: (context) => `${context.raw}%`,
                },
            },
            datalabels: {
                display: true,
                color: '#fff',
                anchor: 'end',
                align: 'start',
                formatter: (value) => `${value}%`,
            },
        },
        scales: {
            x: {
                grid: { display: false },
                ticks: {
                    color: '#888',
                    font: {
                        size: 14,
                    },
                },
            },
            y: {
                display: false,
            },
        },
    };
    const processChartData = (data, chart) => {
        switch (chart) {
            case 'gender':
                return {
                    labels: Object.keys(data),
                    datasets: [
                        {
                            label: 'Gender',
                            data: Object.values(data),
                            backgroundColor: [
                                'rgba(217, 107, 139)',
                                'rgba(101, 105, 225)',
                                'rgba(93, 200, 179)',
                                'rgba(122, 87, 218)',
                            ],
                        },
                    ],
                };
            case 'age':
                return {
                    labels: Object.keys(data),
                    datasets: [
                        {
                            label: 'Age',
                            data: Object.values(data),
                            backgroundColor: [
                                'rgba(217, 107, 139)',
                                'rgba(101, 105, 225)',
                                'rgba(93, 200, 179)',
                                'rgba(122, 87, 218)',
                                'rgba(234, 145, 110)',
                            ],
                        },
                    ],
                };
            case 'location':
                return {
                    labels: Object.keys(data),
                    datasets: [
                        {
                            label: 'Location',
                            data: Object.values(data),
                            backgroundColor: [
                                'rgba(217, 107, 139)',
                                'rgba(101, 105, 225)',
                                'rgba(93, 200, 179)',
                                'rgba(122, 87, 218)',
                                'rgba(234, 145, 110)',
                            ],
                        },
                    ],
                };
        }
    };

    return (
        <div className='basic-info-list'>
            <div className='basic-info-title'>
                Follwers<span className='time-range'>{selectedCreator?.date_range || '--'}</span>
            </div>
            <div className='followers-data-charts'>
                <div className='data-chart'>
                    <div className='chart-title'>Follower Gender</div>
                    {selectedCreator?.followerData?.gender && (
                        <Doughnut
                            data={processChartData(selectedCreator?.followerData?.gender, 'gender')}
                            options={{ ...options, cutout: 60 }}
                        />
                    )}
                </div>
                <div className='data-chart'>
                    <div className='chart-title'>Follower Age</div>
                    {selectedCreator?.followerData?.age && (
                        <Doughnut
                            data={processChartData(selectedCreator?.followerData?.age, 'age')}
                            options={{ ...options, cutout: 60 }}
                        />
                    )}
                </div>
                <div className='data-chart'>
                    <div className='chart-title'>Top 5 Locations</div>
                    {selectedCreator?.followerData?.locations && (
                        <Bar
                            data={processChartData(selectedCreator?.followerData?.locations, 'location')}
                            options={barOptions}
                        />
                    )}
                </div>
            </div>
        </div>
    );
}

function CreatorTrends({ selectedCreator }) {
    const [activeTab, setActiveTab] = useState('gmv');

    const lineOptions = {
        responsive: true,
        maintainAspectRatio: false,
        plugins: {
            legend: {
                position: 'bottom',
            },
        },
    };
    const processChartData = (tab) => {
        return {
            labels: selectedCreator?.trendsData?.dates,
            datasets: [
                {
                    label: tab,
                    data: selectedCreator?.trendsData[tab],
                    fill: false,
                    borderColor: '#6366f1',
                    backgroundColor: '#6366f1',
                    tension: 0.4,
                },
            ],
        };
    };

    return (
        <div className='basic-info-list'>
            <div className='basic-info-title'>
                Trends<span className='time-range'>{selectedCreator?.liveTimeRange || '--'}</span>
            </div>
            <div className='tab-switches'>
                <div
                    className={`tab-switch-item ${activeTab === 'gmv' ? 'active' : ''}`}
                    onClick={() => setActiveTab('gmv')}
                >
                    GMV
                </div>
                <div
                    className={`tab-switch-item ${activeTab === 'items_sold' ? 'active' : ''}`}
                    onClick={() => setActiveTab('items_sold')}
                >
                    Items Sold
                </div>
                <div
                    className={`tab-switch-item ${activeTab === 'followers' ? 'active' : ''}`}
                    onClick={() => setActiveTab('followers')}
                >
                    Followers
                </div>
                <div
                    className={`tab-switch-item ${activeTab === 'video_views' ? 'active' : ''}`}
                    onClick={() => setActiveTab('video_views')}
                >
                    Video Views
                </div>
                <div
                    className={`tab-switch-item ${activeTab === 'engagement_rate' ? 'active' : ''}`}
                    onClick={() => setActiveTab('engagement_rate')}
                >
                    Engagement Rate
                </div>
            </div>
            <div className='line-chart'>
                {selectedCreator?.trendsData && (
                    <Line data={processChartData(activeTab)} options={lineOptions} />
                )}
            </div>
        </div>
    );
}
function CreatorVideos({ selectedCreator }) {
    return (
        <div className='basic-info-list video-list'>
            <div className='basic-info-title'>Videos</div>
            {selectedCreator?.videosData?.regular_videos?.videos?.length > 0 &&
                selectedCreator?.videosData.regular_videos?.videos.map((video) => (
                    <div key={video.id} className='basic-info-item'>
                        <div className='picture' style={{ backgroundImage: `url(${video.thumbnail_url})` }}></div>
                        <div className='right-side-info'>
                            <Crown size={16} className='crown-icon' />
                            <RouterLink to={video.video_url} className='video-title text-dark'>
                                {video.title}
                            </RouterLink>
                            <div className='release-time item-info'>
                                Release Time<span className='time'>{video.release_date}</span>
                            </div>
                            <div className='views item-info'>
                                <FontAwesomeIcon icon='fa-solid fa-eye' style={{ color: '#636AE8FF' }} />
                                {video.view_count}
                            </div>
                            <div className='like item-info'>
                                <FontAwesomeIcon icon='fa-solid fa-heart' style={{ color: '#E8618CFF' }} />
                                {video.like_count}
                            </div>
                        </div>
                    </div>
                ))}

            <div className='basic-info-title'>Videos with Product</div>
            {selectedCreator?.videosData?.product_videos?.videos?.length > 0 &&
                selectedCreator?.videosData?.product_videos?.videos.map((video) => (
                    <div key={video.id} className='basic-info-item'>
                        <div className='picture' style={{ backgroundImage: `url(${video.thumbnail_url})` }}></div>
                        <div className='right-side-info'>
                            <Crown size={16} className='crown-icon' />
                            <RouterLink to={video.video_url} className='video-title text-dark'>
                                {video.title}
                            </RouterLink>
                            <div className='release-time item-info'>
                                Release Time<span className='time'>{video.release_date}</span>
                            </div>
                            <div className='views item-info'>
                                <FontAwesomeIcon icon='fa-solid fa-eye' style={{ color: '#636AE8FF' }} />
                                {video.view_count}
                            </div>
                            <div className='like item-info'>
                                <FontAwesomeIcon icon='fa-solid fa-heart' style={{ color: '#E8618CFF' }} />
                                {video.like_count}
                            </div>
                        </div>
                    </div>
                ))}
        </div>
    );
}

function CollabInfo({ selectedCreator }) {
    return (
        <div className='collab-info'>
            <Table responsive className='bg-white shadow-xs rounded overflow-hidden'>
                <thead>
                    <tr>
                        <th>Brand</th>
                        <th>Pricing Detail</th>
                        <th>Start Date</th>
                        <th>End Date</th>
                        <th>Status</th>
                        <th>GMV Achieved</th>
                        <th>Views Achieved</th>
                        <th>Video Link</th>
                    </tr>
                </thead>
                <tbody>
                    {selectedCreator?.collabInfo?.length > 0 ? (
                        selectedCreator?.collabInfo?.map((collab) => (
                            <tr>
                                <td>{collab.brand}</td>
                                <td>{collab.pricingDetail}</td>
                                <td>{collab.startDate}</td>
                                <td>{collab.endDate}</td>
                                <td>{collab.status}</td>
                            </tr>
                        ))
                    ) : (
                        <tr>
                            <td colSpan={8} className='text-center'>
                                No data
                            </td>
                        </tr>
                    )}
                </tbody>
            </Table>
        </div>
    );
}
