import React, { useState } from 'react';
import DatabaseFilter from '../components/DatabaseFilter';
import CreatorList from '../components/CreatorList';
import SearchBar from '../components/SearchBar';
import { Button } from 'react-bootstrap';
import AddToCampaign from '../components/AddToCampaign';
import { searchCreators } from '../store/slices/creatorsSlice';
import { useDispatch, useSelector } from 'react-redux';

export default function Database({ path }) {
    const [showAddToCampaignModal, setShowAddToCampaignModal] = useState(false);
    const [searchValue, setSearchValue] = useState('');
    const dispatch = useDispatch();
    const { selectedCreators } = useSelector((state) => state.creators);

    const handleSearch = (e) => {
        e.preventDefault();
        dispatch(searchCreators({ q: searchValue, mode: 'or', page: 1, page_size: 10 }));
    };

    return (
        <div className='database-page'>
            <div className='function-bar'>
                <SearchBar onSearch={handleSearch} value={searchValue} onChange={(e) => setSearchValue(e.target.value)} />
                <Button disabled={selectedCreators.length === 0} onClick={() => setShowAddToCampaignModal(true)}>+ Add to Campaign</Button>
            </div>
            <div className='breadcrumb'>
                <div className='breadcrumb-item'>Creator Database</div>
                {path === 'tiktok' && <div className='breadcrumb-item'>TikTok</div>}
                {path === 'instagram' && <div className='breadcrumb-item'>Instagram</div>}
                {path === 'youtube' && <div className='breadcrumb-item'>YouTube</div>}
            </div>
            <DatabaseFilter path={path} pageType={'database'} />
            <CreatorList path={path} />
            <AddToCampaign show={showAddToCampaignModal} onHide={() => setShowAddToCampaignModal(false)} onSubmit={() => setShowAddToCampaignModal(false)} />
        </div>
    );
}
