import { Button, Col, Form, Modal, Row } from 'react-bootstrap';
import SearchBar from '../components/SearchBar';
import { Footprints, Plus } from 'lucide-react';
import React, { useEffect, useState } from 'react';
import { useDispatch } from 'react-redux';
import { addTemplateThunk, editTemplateThunk, fetchTemplates } from '../store/slices/inboxSlice';
import TemplateList from '../components/TemplateList';
import { CAMPAIGN_SERVICES, TEMPLATE_MISSIONS } from '../lib/constant';

export default function InboxTemplate() {
    const [activeTab, setActiveTab] = useState('all');
    const [showAddTemplateModal, setShowAddTemplateModal] = useState(false);
    const [showEditTemplateModal, setShowEditTemplateModal] = useState(false);
    const [formData, setFormData] = useState({
        title: 'TikTok合作邀请',
        content: `Hi {tiktok id},\n\n我是{sender name}，来自OOIN Media。我们对您的TikTok内容印象深刻，希望能就付费推广活动进行合作。\n\n请问您对单个TikTok视频的报价是多少？如果我们计划多个视频合作，是否有批量折扣？\n\n期待您的回复！`,
        mission: 'initial_contact',
        platform: 'tiktok',
        service: 'text',
        collaboration_type: 'paid_promotion',
        is_public: true,
    });
    const dispatch = useDispatch();

    useEffect(() => {
        if (activeTab === 'all') {
            dispatch(fetchTemplates());
        } else {
            dispatch(fetchTemplates({ mission: activeTab }));
        }
    }, [dispatch, activeTab]);

    return (
        <React.Fragment>
            <div className='function-bar'>
                <SearchBar />
                <Button onClick={() => setShowAddTemplateModal(true)}>
                    <Plus />
                    Add Template
                </Button>
            </div>
            <div className='breadcrumb'>
                <div className='breadcrumb-item'>Templates</div>
            </div>
            <div className='tab-switches'>
                <div
                    className={`tab-switch-item ${activeTab === 'all' ? 'active' : ''}`}
                    onClick={() => setActiveTab('all')}
                >
                    全部
                </div>
                <div
                    className={`tab-switch-item ${activeTab === 'initial_contact' ? 'active' : ''}`}
                    onClick={() => setActiveTab('initial_contact')}
                >
                    初步建联
                </div>
                <div
                    className={`tab-switch-item ${activeTab === 'negotiation' ? 'active' : ''}`}
                    onClick={() => setActiveTab('negotiation')}
                >
                    砍价邮件
                </div>
                <div
                    className={`tab-switch-item ${activeTab === 'script' ? 'active' : ''}`}
                    onClick={() => setActiveTab('script')}
                >
                    脚本邮件
                </div>
                <div
                    className={`tab-switch-item ${activeTab === 'follow_up' ? 'active' : ''}`}
                    onClick={() => setActiveTab('follow_up')}
                >
                    合作追踪
                </div>
            </div>
            <TemplateList
                activeTab={activeTab}
                openModal={() => setShowEditTemplateModal(true)}
                setFormData={setFormData}
            />
            <AddTemplateModal
                show={showAddTemplateModal}
                handleClose={() => setShowAddTemplateModal(false)}
                type='add'
                formData={formData}
                setFormData={setFormData}
            />
            <AddTemplateModal
                show={showEditTemplateModal}
                handleClose={() => setShowEditTemplateModal(false)}
                type='edit'
                formData={formData}
                setFormData={setFormData}
            />
        </React.Fragment>
    );
}

function AddTemplateModal({ show, formData, setFormData, handleClose, type = 'add' }) {
    const dispatch = useDispatch();

    const handleChange = (e) => {
        setFormData({
            ...formData,
            [e.target.name]: e.target.value,
        });
    };

    const handleSubmit = () => {
        if (type === 'add') {
            dispatch(addTemplateThunk(formData));
        } else {
            dispatch(editTemplateThunk(formData));
        }
    };

    useEffect(() => {}, [formData]);

    return (
        <Modal show={show} onHide={handleClose} size='lg'>
            <Modal.Header closeButton>
                <Modal.Title>{type === 'add' ? 'Add Template' : 'Edit Template'}</Modal.Title>
            </Modal.Header>
            <Modal.Body>
                <Form>
                    <Form.Group className='mb-3' controlId='formBasicEmail'>
                        <Form.Label>Title</Form.Label>
                        <Form.Control
                            required
                            type='text'
                            placeholder='Enter title'
                            value={formData.title}
                            name='title'
                            onChange={handleChange}
                        />
                    </Form.Group>
                    <Row className='mb-3'>
                        <Form.Group className='col' controlId='formBasicEmail'>
                            <Form.Label>Mission</Form.Label>
                            <Form.Select
                                required
                                type='select'
                                placeholder='Select mission'
                                value={formData.mission}
                                name='mission'
                                onChange={handleChange}
                            >
                                <option value='' disabled>
                                    Select mission
                                </option>
                                {TEMPLATE_MISSIONS.map((mission) => (
                                    <option key={mission.value} value={mission.value}>
                                        {mission.name}
                                    </option>
                                ))}
                            </Form.Select>
                        </Form.Group>
                        <Form.Group className='col' controlId='formBasicEmail'>
                            <Form.Label>Platform</Form.Label>
                            <Form.Select
                                required
                                type='select'
                                placeholder='Select platform'
                                value={formData.platform}
                                name='platform'
                                onChange={handleChange}
                            >
                                <option value='' disabled>
                                    Select platform
                                </option>
                                <option value='tiktok'>TikTok</option>
                                <option value='instagram'>Instagram</option>
                                <option value='facebook'>Facebook</option>
                                <option value='youtube'>Youtube</option>
                            </Form.Select>
                        </Form.Group>
                        <Form.Group className='col' controlId='formBasicEmail'>
                            <Form.Label>合作模式</Form.Label>
                            <Form.Select
                                required
                                type='select'
                                value={formData.service}
                                name='service'
                                onChange={handleChange}
                            >
                                <option value='' disabled>
                                    Select service
                                </option>
                                {CAMPAIGN_SERVICES.map((service) => (
                                    <option key={service.value} value={service.value}>
                                        {service.name}
                                    </option>
                                ))}
                            </Form.Select>
                        </Form.Group>
                    </Row>

                    <Form.Group className='mb-3' controlId='formBasicEmail'>
                        <Form.Label>Template</Form.Label>
                        <Form.Control
                            required
                            type='textarea'
                            as='textarea'
                            rows={10}
                            placeholder='Enter template'
                            value={formData.content}
                            name='content'
                            onChange={handleChange}
                        />
                    </Form.Group>
                </Form>
            </Modal.Body>
            <Modal.Footer>
                <Button variant='outline-primary' className='border-0' onClick={handleClose}>
                    Close
                </Button>
                <Button variant='primary' type='submit' onClick={handleSubmit}>
                    Create
                </Button>
            </Modal.Footer>
        </Modal>
    );
}
