import React, { useState } from 'react';
import SearchBar from '../components/SearchBar';
import { Button } from 'react-bootstrap';
import DatabaseFilter from '../components/DatabaseFilter';
import PrivateCreatorList from '../components/PrivateCreatorList';
import { searchPrivateCreators } from '../store/slices/creatorsSlice';
import { useDispatch, useSelector } from 'react-redux';

export default function PrivateCreator({ path }) {
	const [searchValue, setSearchValue] = useState('');
    const { selectedCreators } = useSelector((state) => state.creators);
    const dispatch = useDispatch();

    const handleSearch = (e) => {
        e.preventDefault();
        dispatch(searchPrivateCreators({ q: searchValue, mode: 'or', page: 1, page_size: 10 }));
    };

    return (
        <div className='private-creator-page'>
            <div className='function-bar'>
                <SearchBar onSearch={handleSearch} value={searchValue} onChange={(e) => setSearchValue(e.target.value)} />
                <Button disabled={selectedCreators.length === 0}>+ Add to Campaign</Button>
            </div>
            <div className='breadcrumb'>
                <div className='breadcrumb-item'>Private Creators</div>
                {path === 'tiktok' && <div className='breadcrumb-item'>TikTok</div>}
                {path === 'instagram' && <div className='breadcrumb-item'>Instagram</div>}
                {path === 'youtube' && <div className='breadcrumb-item'>YouTube</div>}
            </div>
            <DatabaseFilter path={path} pageType={'private'} />
            <PrivateCreatorList path={path} />
        </div>
    );
}
