import axios from 'axios';
import store, { dispatch } from '@/store';
import { clearUser } from '../store/slices/authSlice';
const api = axios.create({
    baseURL: '/api',
    withCredentials: true, // Include cookies if needed
});

api.interceptors.request.use(
    (config) => {
        const token = sessionStorage.getItem('token') || '';
        if (token) {
            config.headers.Authorization = `Token ${token}`;
        }
        return config;
    },
    (error) => {
        console.error('Request error:', error);
        return Promise.reject(error);
    }
);

api.interceptors.response.use(
    (response) => {
        return response;
    },
    (error) => {
        if (error.response.status === 401) {
            sessionStorage.removeItem('token');
            window.location.href = '/login';
            dispatch(clearUser());
        }
        console.log(error);
        return Promise.reject(error.response.data || error);
    }
);

const get = async (url, params) => {
    const response = await api.get(url, params);
    return response.data;
};

const post = async (url, data) => {
    const response = await api.post(url, data);
    return response.data;
};

const put = async (url, data) => {
    const response = await api.put(url, data);
    return response.data;
};

const del = async (url) => {
    const response = await api.delete(url);
    return response.data;
};

const upload = async (url, data) => {
    const response = await api.post(url, data, {
        headers: {
            'Content-Type': 'multipart/form-data',
        },
    });
    return response.data;
};

export default { get, post, put, del, upload };
