import { createAsyncThunk, createSlice } from '@reduxjs/toolkit';
import api from '@/services/api';
import { setNotificationBarMessage } from './notificationBarSlice';
const mockProducts = [
    {
        id: 1,
        name: 'Name',
        commission: '15%',
        openCollab: '12%',
        availableSamples: 10,
        price: '$78.90 - $118.90',
        stock: 884,
        sold: 732,
        rating: 4.2,
        reviews: 58,
        collabCreators: 40,
        tiktokShop: true,
        gmv: '$4k - $10k',
    },
    {
        id: 2,
        name: 'Name',
        commission: '15%',
        openCollab: '12%',
        availableSamples: 10,
        price: '$78.90 - $118.90',
        stock: 884,
        sold: 732,
        rating: 4.2,
        reviews: 58,
        collabCreators: 40,
        tiktokShop: true,
        gmv: '$4k - $10k',
    },
    {
        id: 3,
        name: 'Name',
        commission: '15%',
        openCollab: '12%',
        availableSamples: 10,
        price: '$78.90 - $118.90',
        stock: 884,
        sold: 732,
        rating: 4.2,
        reviews: 58,
        collabCreators: 40,
        tiktokShop: true,
        gmv: '$4k - $10k',
    },
];

const mockCampaigns = [
    {
        id: 1,
        name: 'SUNLINK拍拍灯',
        service: '达人短视频-付费',
        creators: 10,
        creator_type: '带货类达人',
        creator_level: ['L2', 'L3'],
        category: ['家居', '生活', '数码'],
        gmv: '$4k - $10k',
        followers: 10000,
        views: '500 - 10.5k',
        budget: '$10 - $150',
        products: mockProducts,
    },
    {
        id: 2,
        name: 'MINISO',
        service: '达人短视频-付费',
        creators: 10,
        creator_type: '带货类达人',
        creator_level: ['L2', 'L3'],
        category: ['家居', '生活', '数码'],
        gmv: '$4k - $10k',
        followers: 10000,
        views: '500 - 10.5k',
        budget: '$10 - $150',
        products: mockProducts,
    },
];

const mockBrands = [
    {
        id: 1,
        name: 'Sunlink',
        category: 'furniture',
        collab: '3',
        creators: 20,
        source: 'TKS Official',
        description: 'Description 1',
        website: 'https://www.brand1.com',
        campaigns: mockCampaigns,
        products: mockProducts,
    },
    {
        id: 2,
        name: 'MINISO',
        category: 'furniture',
        collab: '5',
        creators: 30,
        source: 'TKS Official',
        description: 'Description 1',
        website: 'https://www.brand1.com',
        campaigns: mockCampaigns,
        products: mockProducts,
    },
];

export const fetchBrands = createAsyncThunk('brands/fetchBrands', async (_, { rejectWithValue, dispatch }) => {
    try {
        const response = await api.get('/brands/');
        if (response.code !== 200) {
            throw new Error(response.message);
        }
        return response.data;
    } catch (error) {
        dispatch(setNotificationBarMessage({ message: error.message, type: 'error' }));
        return rejectWithValue(error.message);
    }
});

export const searchBrands = createAsyncThunk('brands/searchBrands', async (params, { rejectWithValue }) => {
    try {
        const response = await api.get('/brands/search/', { params });
        if (response.code !== 200) {
            throw new Error(response.message);
        }
        return response.data;
    } catch (error) {
        return rejectWithValue(error.message);
    }
});

export const fetchBrandDetail = createAsyncThunk('brands/fetchBrandDetail', async (brandId, { rejectWithValue }) => {
    try {
        const response = await api.get(`/brands/${brandId}/`);
        if (response.code === 200) {
            return response.data;
        }
        throw new Error(response.message);
    } catch (error) {
        return rejectWithValue(error.message);
    }
});
export const fetchBrandCampaigns = createAsyncThunk(
    'brands/fetchBrandCampaigns',
    async (brandId, { rejectWithValue }) => {
        try {
            const response = await api.get(`/brands/${brandId}/campaigns/`);
            console.log(response);
            if (response.code === 200) {
                return response.data;
            }
            throw new Error(response.message);
        } catch (error) {
            return rejectWithValue(error.message);
        }
    }
);

export const fetchBrandProducts = createAsyncThunk(
    'brands/fetchBrandProducts',
    async (brandId, { rejectWithValue }) => {
        try {
            const response = await api.get(`/brands/${brandId}/products/`);
            if (response.code !== 200) {
                throw new Error(response.message);
            }
            return response.data;
        } catch (error) {
            return rejectWithValue(error.message);
        }
    }
);

export const createBrandThunk = createAsyncThunk('brands/createBrand', async (brand, { rejectWithValue, dispatch }) => {
    try {
        const response = await api.post('/brands/', brand);
        if (response.code !== 201 && response.code !== 200) {
            throw new Error(response.message);
        }
    } catch (error) {
        dispatch(setNotificationBarMessage({ message: error.message, type: 'error' }));
        return rejectWithValue(error.message);
    }
});

export const createCampaignThunk = createAsyncThunk(
    'brands/createCampaign',
    async (campaign, { rejectWithValue, dispatch }) => {
        try {
            const response = await api.post('/campaigns/', campaign);
            console.log(response);
            if (response.code !== 201 && response.code !== 200) {
                throw new Error(response.message);
            }
        } catch (error) {
            console.log(error);
            dispatch(setNotificationBarMessage({ message: error.message, type: 'error' }));
            return rejectWithValue(error.message);
        }
    }
);

const initialState = {
    brands: [],
    campaigns: [],
    status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
    error: null,
    selectedBrand: null,
};

const brandsSlice = createSlice({
    name: 'brands',
    initialState,
    reducers: {
        selectBrand: (state, action) => {
            state.selectedBrand = action.payload;
        },
        findBrandById: (state, action) => {
            state.selectedBrand = state.brands.find((brand) => brand.id.toString() === action.payload);
        },
    },
    extraReducers: (builder) => {
        builder
            .addCase(fetchBrands.pending, (state) => {
                state.status = 'loading';
            })
            .addCase(fetchBrands.fulfilled, (state, action) => {
                state.status = 'succeeded';
                state.brands = action.payload;
            })
            .addCase(fetchBrands.rejected, (state, action) => {
                state.status = 'failed';
                state.error = action.error.message;
            })
            .addCase(fetchBrandCampaigns.pending, (state) => {
                state.status = 'loading';
            })
            .addCase(fetchBrandCampaigns.fulfilled, (state, action) => {
                state.status = 'succeeded';
                state.selectedBrand.campaigns = action.payload;
            })
            .addCase(fetchBrandCampaigns.rejected, (state, action) => {
                state.status = 'failed';
                state.error = action.error.message;
            })
            .addCase(fetchBrandProducts.pending, (state) => {
                state.status = 'loading';
            })
            .addCase(fetchBrandProducts.fulfilled, (state, action) => {
                state.status = 'succeeded';
                state.selectedBrand.products = action.payload;
            })
            .addCase(fetchBrandProducts.rejected, (state, action) => {
                state.status = 'failed';
                state.error = action.error.message;
            })
            .addCase(createBrandThunk.pending, (state) => {
                state.status = 'loading';
            })
            .addCase(createBrandThunk.fulfilled, (state, action) => {
                state.status = 'succeeded';
            })
            .addCase(createBrandThunk.rejected, (state, action) => {
                state.status = 'failed';
                state.error = action.error.message;
            })
            .addCase(fetchBrandDetail.pending, (state) => {
                state.status = 'loading';
            })
            .addCase(fetchBrandDetail.fulfilled, (state, action) => {
                state.status = 'succeeded';
                state.selectedBrand = action.payload;
            })
            .addCase(fetchBrandDetail.rejected, (state, action) => {
                state.status = 'failed';
                state.error = action.error.message;
            })
            .addCase(createCampaignThunk.pending, (state) => {
                state.status = 'loading';
            })
            .addCase(createCampaignThunk.fulfilled, (state, action) => {
                state.status = 'succeeded';
            })
            .addCase(createCampaignThunk.rejected, (state, action) => {
                state.status = 'failed';
                state.error = action.error.message;
            })
            .addCase(searchBrands.pending, (state) => {
                state.status = 'loading';
            })
            .addCase(searchBrands.fulfilled, (state, action) => {
                state.status = 'succeeded';
                state.brands = action.payload;
            })
            .addCase(searchBrands.rejected, (state, action) => {
                state.status = 'failed';
                state.error = action.error.message;
            });
    },
});

export const { selectBrand, findBrandById, setSelectedProduct } = brandsSlice.actions;

export default brandsSlice.reducer;
