import { createAsyncThunk, createSlice } from "@reduxjs/toolkit";
import api from "@/services/api";

export const fetchCampaigns = createAsyncThunk('brands/fetchCampaigns', async (_, { rejectWithValue }) => {
	try {
			const response = await api.get('/campaigns/');
			if (response.code !== 200) {
					throw new Error(response.message);
			}
			return response.data;
	} catch (error) {
			return rejectWithValue(error.message);
	}
});

export const fetchCampaignDetail = createAsyncThunk('brands/fetchCampaignDetail', async (campaignId, { rejectWithValue }) => {
	try {
			const response = await api.get(`/campaigns/${campaignId}/`);
			if (response.code === 200) {
					return response.data;
			}
			throw new Error(response.message);
	} catch (error) {
			return rejectWithValue(error.message);
	}
});

export const fetchMatchingResult = createAsyncThunk('brands/fetchMatchingResult', async (query, { rejectWithValue }) => {
    try {
        const response = await api.post('/operation/sql_search/', query);
        if (response.code !== 200) {
            throw new Error(response.message);
        }
        return response.data;
    } catch (error) {
        return rejectWithValue(error.message);
    }
});

const initialState = {
    campaigns: [],
    currentCampaign: null,
    status: 'idle',
    error: null,
};

const campaignSlice = createSlice({
    name: 'campaign',
    initialState,
    reducers: {
        setCurrentCampaign: (state, action) => {
            state.currentCampaign = action.payload;
        },
        resetCurrentCampaign: (state) => {
            state.currentCampaign = null;
        },
    },
    extraReducers: (builder) => {
        builder
            .addCase(fetchCampaigns.pending, (state) => {
                state.status = 'loading';
            })
            .addCase(fetchCampaigns.fulfilled, (state, action) => {
                state.status = 'succeeded';
                state.campaigns = action.payload;
            })
            .addCase(fetchCampaigns.rejected, (state, action) => {
                state.status = 'failed';
                state.error = action.payload;
            })
            .addCase(fetchCampaignDetail.pending, (state) => {
                state.status = 'loading';
            })
            .addCase(fetchCampaignDetail.fulfilled, (state, action) => {
                state.status = 'succeeded';
                state.currentCampaign = action.payload;
            })
            .addCase(fetchCampaignDetail.rejected, (state, action) => {
                state.status = 'failed';
                state.error = action.payload;
            })
            .addCase(fetchMatchingResult.pending, (state) => {
                state.status = 'loading';
            })
            .addCase(fetchMatchingResult.fulfilled, (state, action) => {
                state.status = 'succeeded';
                state.currentCampaign.matching_result = action.payload.results;
            })
            .addCase(fetchMatchingResult.rejected, (state, action) => {
                state.status = 'failed';
                state.error = action.payload;
            });
    },
});

export const { setCurrentCampaign, resetCurrentCampaign } = campaignSlice.actions;
export default campaignSlice.reducer;
