import { createSlice } from '@reduxjs/toolkit';

const initialState = {
    category: [],
    e_commerce_level: [],
    exposure_level: [],
    gmv_range: [],
    views_range: [0, 100000],
    pricing: [0, 3000],
    // sortBy: 'followers',
    // sortDirection: 'desc',
    platform: '',
};
const filtersSlice = createSlice({
    name: 'filters',
    initialState,
    reducers: {
        setCategory: (state, action) => {
            const category = action.payload;
            if (state.category.includes(category)) {
                state.category = state.category.filter((r) => r !== category);
            } else {
                state.category.push(category);
            }
        },
        toggleEcommerceRating: (state, action) => {
            const rating = action.payload;
            if (state.e_commerce_level.includes(rating)) {
                state.e_commerce_level = state.e_commerce_level.filter((r) => r !== rating);
            } else {
                state.e_commerce_level.push(rating);
            }
        },
        toggleExposureRating: (state, action) => {
            const rating = action.payload;
            if (state.exposure_level.includes(rating)) {
                state.exposure_level = state.exposure_level.filter((r) => r !== rating);
            } else {
                state.exposure_level.push(rating);
            }
        },
        toggleGmvRange: (state, action) => {
            const range = action.payload;
            if (state.gmv_range.includes(range)) {
                state.gmv_range = state.gmv_range.filter((r) => r !== range);
            } else {
                state.gmv_range.push(range);
            }
        },
        setViewsRange: (state, action) => {
            state.views_range = action.payload;
        },
        setPricingRange: (state, action) => {
            state.pricing = action.payload;
        },
        setSortBy: (state, action) => {
            // 如果选择了当前已激活的排序项，则切换排序方向
            if (state.sortBy === action.payload) {
                state.sortDirection = state.sortDirection === 'asc' ? 'desc' : 'asc';
            } else {
                // 否则设置新的排序项，并重置排序方向为降序
                state.sortBy = action.payload;
                state.sortDirection = 'desc';
            }
        },
        setPlatform: (state, action) => {
            state.platform = action.payload;
        },
        resetFilters: () => {
            return initialState;
        },
    },
});

export const {
    setCategory,
    toggleEcommerceRating,
    toggleExposureRating,
    toggleGmvRange,
    setViewsRange,
    setPricingRange,
    setSortBy,
    setPlatform,
    resetFilters,
} = filtersSlice.actions;

export default filtersSlice.reducer;
